@@ -91,6 +91,7 @@ DimensionSettings.initPreferences = function(pageWidget, calledByPrefDialog, doc
     var wastz = widgets["AngularShowTrailingZeros"];
     var wap = widgets["AngularPrecision"];
     var wdf = widgets["DimensionFont"];
+    var wdp = widgets["DecimalPoint"];
     var wfg = widgets["FontGroup"];
     var wkp = widgets["KeepProportions"];
 
@@ -131,6 +132,24 @@ DimensionSettings.initPreferences = function(pageWidget, calledByPrefDialog, doc
         });
     }
 
+    // decimal point:
+    if (!isNull(wdp)) {
+        wdp.addItem(". (" + qsTr("point") + ")", '.'.charCodeAt(0));
+        wdp.addItem(", (" + qsTr("comma") + ")", ','.charCodeAt(0));
+        wdp.addItem("  (" + qsTr("space") + ")", ' '.charCodeAt(0));
+        var dimdsep = RSettings.getIntValue(settingsName + "/DecimalPoint", '.'.charCodeAt(0));
+        if (dimdsep===0) {
+            dimdsep = '.'.charCodeAt(0);
+        }
+
+        wdp.currentIndex = wdp.findData(dimdsep);
+
+        wdp["activated(int)"].connect(function() {
+            DimensionSettings.updateLinearPreview(widgets);
+            DimensionSettings.updateAngularPreview(widgets);
+        });
+    }
+
     // init linear dimension format combo boxes:
     if (!isNull(wlf)) {
         wlf.addItem(qsTr("Scientific"), RS.Scientific);
@@ -321,6 +340,17 @@ DimensionSettings.initPreferences = function(pageWidget, calledByPrefDialog, doc
         wastz.setProperty("Loaded", true);
     }
 
+    // decimal separator:
+    if (!isNull(wdp)) {
+        var dimdsep = document.getKnownVariable(RS.DIMDSEP, '.');
+        if (dimdsep===0) {
+            dimdsep = '.'.charCodeAt(0);
+        }
+
+        wdp.currentIndex = wdp.findData(dimdsep);
+        wdp.setProperty("Loaded", true);
+    }
+
     // update unit labels, preview:
     DimensionSettings.updateUnit(unit);
 
@@ -546,6 +576,10 @@ DimensionSettings.updateAngularPrecision = function(widgets) {
 DimensionSettings.updateLinearPreview = function(widgets) {
     var wFormat = widgets["LinearFormat"];
     var showTrailingZeros = isNull(widgets["LinearShowTrailingZeros"]) ? false : widgets["LinearShowTrailingZeros"].checked;
+    var dimdsep = isNull(widgets["DecimalPoint"]) ? '.'.charCodeAt(0) : widgets["DecimalPoint"].itemData(widgets["DecimalPoint"].currentIndex);
+    if (isNull(dimdsep)) {
+        dimdsep = '.'.charCodeAt(0);
+    }
     var value = 14.43112351;
     if (showTrailingZeros===true && RUnit.isMetric(DimensionSettings.unit)) {
         value = 10.0;
@@ -560,7 +594,9 @@ DimensionSettings.updateLinearPreview = function(widgets) {
                 wFormat.itemData(wFormat.currentIndex),
                 widgets["LinearPrecision"].currentIndex,
                 false, false,
-                showTrailingZeros);
+                showTrailingZeros,
+                false,
+                dimdsep);
         if (prev==="") {
             prev = "N/A";
         }
@@ -571,6 +607,10 @@ DimensionSettings.updateLinearPreview = function(widgets) {
 DimensionSettings.updateAngularPreview = function(widgets) {
     var wFormat = widgets["AngularFormat"];
     var showTrailingZeros = widgets["AngularShowTrailingZeros"].checked;
+    var dimdsep = isNull(widgets["DecimalPoint"]) ? '.'.charCodeAt(0) : widgets["DecimalPoint"].itemData(widgets["DecimalPoint"].currentIndex);
+    if (isNull(dimdsep)) {
+        dimdsep = '.'.charCodeAt(0);
+    }
     var value = RMath.deg2rad(37.15357578);
     if (showTrailingZeros===true) {
         value = RMath.deg2rad(60.0);
@@ -584,7 +624,8 @@ DimensionSettings.updateAngularPreview = function(widgets) {
         prev = RUnit.formatAngle(value,
                 wFormat.itemData(wFormat.currentIndex),
                 widgets["AngularPrecision"].currentIndex,
-                showTrailingZeros);
+                true, showTrailingZeros,
+                dimdsep);
         if (prev==="") {
             prev = "N/A";
         }
@@ -618,6 +659,9 @@ DimensionSettings.savePreferences = function(pageWidget, calledByPrefDialog, doc
     widgets["ArchitecturalTick"].setProperty("Saved", true);
     widgets["Arrow"].setProperty("Saved", true);
 
+    // decimal point:
+    document.setKnownVariable(RS.DIMDSEP, widgets["DecimalPoint"].itemData(widgets["DecimalPoint"].currentIndex), transaction);
+
     // dimension format / precision:
     document.setKnownVariable(RS.DIMLUNIT, widgets["LinearFormat"].currentIndex+1, transaction);
     document.setKnownVariable(RS.DIMDEC, widgets["LinearPrecision"].currentIndex, transaction);
